<?php

//  Set Error Reporting - errors only, no warnings / notices
//	You might want to change this to see ALL errors for development

error_reporting(E_ERROR);

//	NOTE - examples of the calls to the methods can be found in the index.php file.  For full documentation consult TranslateMedia API Docs  - http://translatemedia.com/api/

//  Definitions of constants

//  Quote Types
define("DRAFT", 0);
define("PREMIUM", 1);
define("DRAFT_EXPRESS", 2);
define("PREMIUM_EXPRESS", 3);

//  Authenticity Certification Types
define("NO_AUTHENTICITY_CERTIFICATION", 0);
define("LETTER_OF_AUTHENTICITY", 1);
define("NOTARISATION", 2);
define("AFFIDAVIT", 3);

//  Naming Convention constants
define("TRANSLATE_MEDIA_CONVENTION", 0);
define("KEEP_ORIGINAL_FILENAME", 1);
define("USE_PREFIX_AND_SUFFIX", 2);
define("USE_PREFIX_AND_SUFFIX_AS_FILENAME", 3);


//  Format for XML date production from PHP date time
define('CONST_API_DATETIMESTAMP', 'Y-m-d\TH:i:sP');

//	Class definition starts here

class cTMAPI
{

//  Following variables should not be set directly, but should be set through
//  a call to the constructor.

var $userid;
var $apikey;
var $wsdl;
var $namespace;


//  The client object is used throughout the
//  class to access the API.  It is initialised by the constructor

var $client;

//  The initialised property is set by the constructor to
//  indicate that the class has been properly initialised

var $isInitialised=false;

//  $lasterror is the last reported error / response from the any call.
var $lasterror='';

//  $AuthenticateResult stores the result of the authentication process.  This can be used in other
//  calls to the class.
var $AuthenticationToken;


public function __construct($userid="", $apikey="", $wsdl="", $namespace="") {


    $this->userid=$userid;
    $this->apikey=$apikey;
    $this->wsdl=$wsdl;
    $this->namespace=$namespace;

    
    try
    {
        $this->client = new SoapClient($wsdl);
        //  Authentication for the the TranslateMedia STREAM service requires 
		//	the username and ApiKey to be sent
        $authheaderbody=array('Username'=>$userid, 'ApiKey'=>$apikey);
        $header = new SOAPHeader($namespace, 'AuthenticationHeader', $authheaderbody);   
        $this->client->__setSoapHeaders($header); 
        $result=$this->client->Authenticate();
    
        
	    if ($result->AuthenticateResult->authenticationSuccessful)
        {
			//	If successful....
            $this->AuthenticationToken=$result->AuthenticateResult;
            $this->isInitialised=true;
            return true;
        }
        else
        {
			//	If failed, set token to Null and return false
            $this->AuthenticationToken=null;
            $this->lasterror=$result->AuthenticateResult->m_errors->description;
            return false;
        }
        
       
    }
    catch (Exception $e)
    {
		//	Here we have an error
        var_dump($e);
    } 
    
    //  Finally get here and if we get through the above without
    //  userid, etc. set then mark as uninitialised
    
    if ($userid="") $this->isInitialised=false;
    if ($apikey="") $this->isInitialised=false;    
    if ($wsdl="") $this->isInitialised=false;    
    if ($namespace="") $this->isInitialised=false;    
    
    if (!$this->isInitialised)
    {
        $this->lasterror="Error in initialising STREAM API connection. Check parameters passed to class.";
    }
    
    
        
} // end func: __construct


//	Returns a STREAMResponse object containing a language list
public function GetLanguagesList()
{

    if (!$this->isInitialised) return new STREAMResponse(false, "ERR - STREAM API connection not initialised / authenticated",null);
    try
    {
        $body=array( 
            "GetLanguagesList" => array( )
        );
        $result=$this->client->__soapCall("GetLanguagesList",$body);   
        return new STREAMResponse(true, "OK" ,$result->GetLanguagesListResult);
    }
    catch (Exception $e)
    {
        $this->lasterror=$e->getMessage();
        return new STREAMResponse(false, $this->lasterror,null);
    } 
    
}


//	Returns a STREAMResponse object containing the language ID
public function GetLanguageID($sLanguageName)
{

    if (!$this->isInitialised) return new STREAMResponse(false, "ERR - STREAM API connection not initialised / authenticated",null);
    try
    {
	    $body=array( 
            "GetLanguageID" => array( "text"=>$sLanguageName )
        );
	
        $result=$this->client->__soapCall("GetLanguageID",$body);   
        return new STREAMResponse(true, "OK",$result->GetLanguageIDResult->languageID);

    }
    catch (Exception $e)
    {
        $this->lasterror=$e->getMessage();
        return new STREAMResponse(false, $this->lasterror,null);
    } 
    
}

//	Returns Language ID for given RFC code
//  returns -1 if language rfc code doesn't exist
public function GetLanguageIdRfc5646 ($sRFCCode)
{

    if (!$this->isInitialised) return new STREAMResponse(false, "ERR - STREAM API connection not initialised / authenticated",null);
    try
    {
	    $body=array( 
            "GetLanguageIdRfc5646" => array( "rfc5646Code"=>$sRFCCode )
        );
	
        $result=$this->client->__soapCall("GetLanguageIdRfc5646",$body);   
        return new STREAMResponse(true, "OK",$result->GetLanguageIdRfc5646Result->languageID);


    }
    catch (Exception $e)
    {
        $this->lasterror=$e->getMessage();
        return new STREAMResponse(false, $this->lasterror,null);

    } 
    
}


//	Returns a STREAMResponse object with list of ALL specialities in it
public function GetSpecialitiesList()
{

    if (!$this->isInitialised) return new STREAMResponse(false, "ERR - STREAM API connection not initialised / authenticated",null);
    try
    {
	    $body=array( 
            "GetSpecialitiesList" => array( )
        );
	
        $result=$this->client->__soapCall("GetSpecialitiesList",$body); 
        return new STREAMResponse(true, "OK" ,$result->GetSpecialitiesListResult);    

    }
    catch (Exception $e)
    {
        $this->lasterror=$e->getMessage();
        return new STREAMResponse(false, $this->lasterror,null);

    } 
    
}

//	Returns a STREAMResponse object with list of specialities in it
//	for the specified language ID
public function GetAvailableSpecialities($iSourceLanguageID)
{

    if (!$this->isInitialised) return new STREAMResponse(false, "ERR - STREAM API connection not initialised / authenticated",null);
    try
    {
	    $body=array( 
            "GetAvailableSpecialities" => array( "idSourceLng"=>$iSourceLanguageID )
        );
	
        $result=$this->client->__soapCall("GetAvailableSpecialities",$body);   
        
        if (property_exists($result,"SOAPspeciality"))
        {
            return new STREAMResponse(true, "OK",$result->GetAvailableSpecialitiesResult);
        }
        else
        {
            return new STREAMResponse(false, "ERR - No Specialities available",null);
        }

    }
    catch (Exception $e)
    {
        $this->lasterror=$e->getMessage();
        return new STREAMResponse(false, $this->lasterror,null);

    } 
    
}

//	Returns a STREAMResponse object with a list of target languages
//	for the specified source language and speciality
public function GetAvailableTargetLanguages($iSourceLanguage, $iSpeciality)
{

    if (!$this->isInitialised) return new STREAMResponse(false, "ERR - STREAM API connection not initialised / authenticated",null);
    try
    {
	$body=array( 
        "GetAvailableTargetLanguages" => array(
            "idSourceLng"        => $iSourceLanguage,
            "idSpeciality"       => $iSpeciality
        )
    );

	
        $result=$this->client->__soapCall("GetAvailableTargetLanguages",$body);   

        
        if (property_exists($result->GetAvailableTargetLanguagesResult,"SOAPlanguage"))
        {
            return new STREAMResponse(true, "OK",$result->GetAvailableTargetLanguagesResult);
        }
        else
        {
            return new STREAMResponse(false, "ERR - No languages available for that source language / specialism",null);
        }

    }
    catch (Exception $e)
    {
        $this->lasterror=$e->getMessage();
        return new STREAMResponse(false, $this->lasterror,null);

    } 
    
}


/*=============================================================================================

QUOTE METHODS
The following methods access the quote functionality of the STREAM API

==============================================================================================*/



//	Returns a STREAMResponse object containing a set of quotes for
//	the translation request passed in. Source language and speciality passed
//	in as an integer IDs, target languages passed in as an array
public function GetQuoteForPlainText ($iSourceLanguage, $iSpeciality, $sTargetLanguages, $sSourceText='')
{

    //  Before using API do a little sanity checking
    if ($sSourceText=='') return new STREAMResponse(false, "ERR - No source text entered for translation",null);
    if (!$this->isInitialised) return new STREAMResponse(false, "ERR - STREAM API connection not initialised / authenticated",null);

    try
    {

	$header = new SOAPHeader($this->namespace, 'AuthenticationToken', $this->AuthenticationToken);      
 	
	$body=array( 
        "GetQuoteForPlainText" => array( 
            "idSourceLng"        => $iSourceLanguage, 
            "idSpecialism"    => $iSpeciality,
		    "aidTargetLng" =>$sTargetLanguages,
		    "sSourceText" =>$sSourceText
        ) 
    );
	
	//  Now make the call
    $result=$this->client->__soapCall("GetQuoteForPlainText",$body,NULL, $header);    
    
    //  Now look at result.
    if ($result->GetQuoteForPlainTextResult->requestSuccessful)
    {
    
        return new STREAMResponse(true, "OK", $result->GetQuoteForPlainTextResult->m_quotes);
    
    }
    else
    {
        return new STREAMResponse(false, $result->GetQuoteForPlainTextResult->m_errors->description,null);
    }
    
    

    }
    catch (Exception $e)
    {
        $this->lasterror=$e->getMessage();
        return new STREAMResponse(false, $this->lasterror,null);

    } 
    
}

//	returns a STREAMResponse object containing quotes.
//	the translation request passed in. Source language and speciality passed
//	in as integer IDs, target languages passed in as an array

    //	FilenameAndPath is the full filename and path to the document file being
//	processed on the LOCAL server.  The FileName is the name that you want 
//	the translation to be processed as in the API - no path.

public function GetQuoteForDocument($iSourceLanguage, $iSpeciality, $sTargetLanguages, $sFileNameAndPath="", $sFileName="")
{

    if (!$this->isInitialised) return new STREAMResponse(false, "ERR - STREAM API connection not initialised / authenticated",null);
    if ($sFileName=='') return new STREAMResponse(false, "ERR - Filename must be passed",null);
    if ($sFileNameAndPath=='') return new STREAMResponse(false, "ERR - Filename and path must be passed",null);    
    try
    {
    
            $header = new SOAPHeader($this->namespace, 'AuthenticationToken', $this->AuthenticationToken);     
 	

            //  open the file and read the contents into a byte array
            $byteArray=base64_encode(file_get_contents($sFileNameAndPath));

        
	        $body=array( 
            "GetQuoteForDocument" => array( 
                "idSourceLng"        => $iSourceLanguage,
                "idSpecialism" => $iSpeciality,
                "aidTargetLng"=>$sTargetLanguages,
                "sFileNameAndPath" => $sFileNameAndPath,
                "sFileName"=>$sFileName,
                "abyBuffer" => $byteArray
	        ));
        
               
        
        $result=$this->client->__soapCall("GetQuoteForDocument",$body,NULL, $header);    
    
        //  Now look at result.
        if ($result->GetQuoteForDocumentResult->requestSuccessful)
        {
    
            return new STREAMResponse(true, "OK", $result->GetQuoteForDocumentResult->m_quotes);
    
        }
        else
        {
            return new STREAMResponse(false, $result->GetQuoteForDocumentResult->m_errors->description,null);
        }
    

    }
    catch (Exception $e)
    {
        $this->lasterror=$e->getMessage();
        return new STREAMResponse(false, $this->lasterror,null);

    } 
    
}


//	returns a STREAMResponse object containing quotes.
//	the translation request passed in. Source language and speciality passed
//	in as integer IDs, target languages passed in as an array

    //	FilenameAndPath is the full filename and path to the document file being
//	processed on the LOCAL server.  The FileName is the name that you want 
//	the translation to be processed as in the API - no path.

public function GetAdvancedQuoteForDocument($iSourceLanguage, $iSpeciality, $sTargetLanguages, $sFileNameAndPath="", $sFileName="", $byAuthenticityCertification=0, $bPartialtranslationRequired=false, $iWordsToTranslate=0)
{

    if (!$this->isInitialised) return new STREAMResponse(false, "ERR - STREAM API connection not initialised / authenticated",null);
    if ($sFileName=='') return new STREAMResponse(false, "ERR - Filename must be passed",null);
    if ($sFileNameAndPath=='') return new STREAMResponse(false, "ERR - Filename and path must be passed",null);      
    try
    {
    
       $header = new SOAPHeader($this->namespace, 'AuthenticationToken', $this->AuthenticationToken);     
 	

        //  open the file and read the contents into a byte array
        $byteArray=base64_encode(file_get_contents($sFileNameAndPath));

        
	    $body=array( 
        "GetAdvancedQuoteForDocument" => array( 
            "idSourceLng"        => $iSourceLanguage,
            "idSpecialism" => $iSpeciality,
            "aidTargetLng"=>$sTargetLanguages,
            "sFileNameAndPath" => $sFileNameAndPath,
            "sFileName"=>$sFileName,
            "abyBuffer" => $byteArray,
            "byAuthenticiyCertification"=>$byAuthenticityCertification,
            "bTranslatePartialDoc"=>$bPartialtranslationRequired,
            "iWordCountToTranslate"=>$iWordsToTranslate       
	    ));
        
               
        
    $result=$this->client->__soapCall("GetAdvancedQuoteForDocument",$body,NULL, $header);        
    //  Now look at result.
    if ($result->GetAdvancedQuoteForDocumentResult->requestSuccessful)
    { 
        return new STREAMResponse(true, "OK", $result->GetAdvancedQuoteForDocumentResult->m_quotes);
    }
    else
    {
        return new STREAMResponse(false, $result->GetAdvancedQuoteForDocumentResult->m_errors->description,null);
    }    


    }
    catch (Exception $e)
    {
        $this->lasterror=$e->getMessage();
        return new STREAMResponse(false, $this->lasterror,null);

    } 
    
}

//	returns a STREAMResponse object containing quotes.
//	the translation request passed in. Source language and speciality passed
//	in as integer IDs, target languages passed in as an array
//	DocumentID will have been returned from previous calls - see docs
public function GetSimpleQuote($iSourceLanguage, $iSpeciality, $sTargetLanguages, $iWordCount, $iDocumentID=0)
{

    if (!$this->isInitialised) return new STREAMResponse(false, "ERR - STREAM API connection not initialised / authenticated",null);
    if ($iDocumentID==0) return new STREAMResponse(false, "ERR - Document ID must be passed",null);
    try
    {
    
            $header = new SOAPHeader($this->namespace, 'AuthenticationToken', $this->AuthenticationToken);     
 	
   
	        $body=array( 
            "GetSimpleQuote" => array( 
                "idSourceLng"        => $iSourceLanguage,
                "idSpecialism" => $iSpeciality,
                "aidTargetLng"=>$sTargetLanguages,
                "wordCount" => $iWordCount,
                "idDocument"=>$iDocumentID
                
	        ));
        
               
        
        $result=$this->client->__soapCall("GetSimpleQuote",$body,NULL, $header);    
    
        //  Now look at result.
        if ($result->GetSimpleQuoteResult->requestSuccessful)
        {
    
            return new STREAMResponse(true, "OK", $result->GetSimpleQuoteResult->m_quotes);
    
        }
        else
        {
            return new STREAMResponse(false, $result->GetSimpleQuoteResult->m_errors->description,null);
        }    


    }
    catch (Exception $e)
    {
        $this->lasterror=$e->getMessage();
        return new STREAMResponse(false, $this->lasterror,null);

    } 
    
}

//	returns a STREAMResponse object containing quotes.
//	the translation request passed in. Source language and speciality passed
//	in as integer IDs, target languages passed in as an array
//	FilenameAndPath is the full filename and path to the document file being sent
//	DocumentID will have been returned from previous calls - see docs
public function GetAdvancedQuote($iSourceLanguage, $iSpeciality, $sTargetLanguages, $iDocumentID, $byAuthenticityCertification, $bPartialtranslationRequired, $iWordsToTranslate)
{

    if (!$this->isInitialised) return new STREAMResponse(false, "ERR - STREAM API connection not initialised / authenticated",null);
    try
    {

               $header = new SOAPHeader($this->namespace, 'AuthenticationToken', $this->AuthenticationToken);     
 	
   
	        $body=array( 
            "GetAdvancedQuote" => array( 
                "idSourceLng"        => $iSourceLanguage,
                "idSpecialism" => $iSpeciality,
                "aidTargetLng"=>$sTargetLanguages,
                "wordCount" => $iWordCount,
                "idDocument"=>$iDocumentID,
                "byAuthenticiyCertification"=>$byAuthenticityCertification,
                "bTranslatePartialDoc"=>$bPartialtranslationRequired,
                "iWordCountToTranslate"=>$iWordsToTranslate                  
                
	        ));
        
               
        
        $result=$this->client->__soapCall("GetAdvancedQuote",$body,NULL, $header);    
    
        //  Now look at the result.
        if ($result->GetAdvancedQuote->requestSuccessful)
        {
    
            return new STREAMResponse(true, "OK", $result->GetAdvancedQuote->m_quotes);
    
        }
        else
        {
            return new STREAMResponse(false, $result->GetAdvancedQuote->m_errors->description,null);
        }    

    }
    catch (Exception $e)
    {
        $this->lasterror=$e->getMessage();
        return new STREAMResponse(false, $this->lasterror,null);

    } 
    
}

/*=============================================================================================

ORDERS METHODS
The following methods access the Order functionality of the STREAM API

==============================================================================================*/

//	Create an order in the system based on quoteID
public function CreateOrder($iQuoteID)
{

    if (!$this->isInitialised) return new STREAMResponse(false, "ERR - STREAM API connection not initialised / authenticated",null);
    try
    {
    
	$header = new SOAPHeader($this->namespace, 'AuthenticationToken', $this->AuthenticationToken);      
 	
	$body=array( 
    "CreateOrder" => array( 
        "idQuote"        => $iQuoteID
	));
	
	
	//  Now make the call
    $result=$this->client->__soapCall("CreateOrder",$body,NULL, $header);        
    
    $orderdetails=$result->CreateOrderResult;
    
    if ($orderdetails->requestSuccessful)
    {
         return new STREAMResponse(true, "OK",$orderdetails->id);   
    }
    else
    {
        return new STREAMResponse(false, "ERR " . $orderdetails->m_errors->description,null);         
    }


    }
    catch (Exception $e)
    {
        $this->lasterror=$e->getMessage();
        return new STREAMResponse(false, $this->lasterror,null);        
    } 
    
}

//	Create an order in the system based on QuoteId with additional parameters.
public function CreateOrderAdvanced($iQuoteID, $sAdditionalInstructions="", $iNamingConvention=0, $sPrefix="", $sSuffix="", $sDeliveryEmailCopyTo="", $bSendForReview=false, $dtReviewerDeadline="", $sPO="")
{

    if (!$this->isInitialised) return new STREAMResponse(false, "ERR - STREAM API connection not initialised / authenticated",null);    
    if ($dtReviewerDeadline=='') $dtReviewerDeadline=$this->convertDateToDateTime('now');
    
        try
        {

    	    $header = new SOAPHeader($this->namespace, 'AuthenticationToken', $this->AuthenticationToken);      
 	
	    $body=array( 
        "CreateOrderAdvanced" => array( 
            "idQuote"        => $iQuoteID,
            "sAdditionalInstructions" => $sAdditionalInstructions,
            "byNamingConvention" => $iNamingConvention,
            "sPrefix"=>$sPrefix,
            "sSuffix"=>$sSuffix,
            "sDeliveryEmailCopyTo" => $sDeliveryEmailCopyTo,
            "bSendForReview" => $bSendForReview,
            "dtReviewerDeadline"=>$dtReviewerDeadline,
            "sPO" => $sPO
	    ));

    
	    //  Now make the call
        $result=$this->client->__soapCall("CreateOrderAdvanced",$body,NULL, $header);                
        $orderdetails=$result->CreateOrderAdvancedResult;
        if ($orderdetails->requestSuccessful)
        {
             return new STREAMResponse(true, "OK",$orderdetails->id);   
        }
        else
        {
            return new STREAMResponse(false, "ERR " . $orderdetails->m_errors->description,null);         
        }

    }
    catch (Exception $e)
    {
        $this->lasterror=$e->getMessage();
        return new STREAMResponse(false, $this->lasterror,null);

    } 
    
}

//	Update your account billing details
public function SaveBillingDetails($sOrderRef, $sBillingName="", $sBillingContact="", $sBillingEmail="", $sBillingAddress="", $sBudgetCode="", $sProjectCode="", $sPO="")
{

    if (!$this->isInitialised) return new STREAMResponse(false, "ERR - STREAM API connection not initialised / authenticated",null);
    try
    {

   	    $header = new SOAPHeader($this->namespace, 'AuthenticationToken', $this->AuthenticationToken);      
 	
	    $body=array( 
        "SaveBillingDetails" => array( 
            "sOrderRef"        => $sOrderRef,
            "sBillingName" => $sBillingName,
            "sBillingContact" => $sBillingContact,
            "sBillingEmail"=>$sBillingEmail,
            "sBillingAddress"=>$sBillingAddress,
            "sBudgetCode" => $sBudgetCode,
            "sProjectCode" => $sProjectCode,
            "sPO" => $sPO
	    ));

    
	    //  Now make the call
        $result=$this->client->__soapCall("SaveBillingDetails",$body,NULL, $header);                
        $billingdetails=$result->SaveBillingDetailsResult;
        
       
        
        if ($billingdetails->requestSuccessful)
        {
             return new STREAMResponse(true, "OK",$billingdetails->id);   
        }
        else
        {
            return new STREAMResponse(false, "ERR " . $billingdetails->m_errors->description,null);         
        }    
    
    
    

    }
    catch (Exception $e)
    {
        $this->lasterror=$e->getMessage();
        return new STREAMResponse(false, $this->lasterror,null);

    } 
    
}


//	For a specified order, upload a document containing further instructions
//	FileNameAndPath and FileName are as detailed previously.
public function UploadMoreInfoDocument($sOrderRef="", $sFileNameAndPath="", $sFileName="")
{

    if (!$this->isInitialised) return new STREAMResponse(false, "ERR - STREAM API connection not initialised / authenticated",null);
    if ($sOrderRef=='') return new STREAMResponse(false, "ERR - Order Ref must be passed",null);
    if ($sFileName=='') return new STREAMResponse(false, "ERR - Filename must be passed",null);
    if ($sFileNameAndPath=='') return new STREAMResponse(false, "ERR - Filename and path must be passed",null);
    try
    {
  	    $header = new SOAPHeader($this->namespace, 'AuthenticationToken', $this->AuthenticationToken);      
 	

        //  open the file and read the contents in to a byte array
        $byteArray=base64_encode(file_get_contents($sFileNameAndPath));
        
	    $body=array( 
        "UploadMoreInfoDocument" => array( 
            "sOrderRef"        => $sOrderRef,
            "sFileName" => $sFileName,
            "abyBuffer" => $byteArray
	    ));
        
        
	    //  Now make the call
        $result=$this->client->__soapCall("UploadMoreInfoDocument",$body,NULL, $header);               
        $updatedata=$result->UploadMoreInfoDocumentResult;
        
       
        
        if ($updatedata->requestSuccessful)
        {
             return new STREAMResponse(true, "OK",$updatedata->id);   
        }
        else
        {
            return new STREAMResponse(false, "ERR " . $updatedata->m_errors->description,null);         
        }        


    }
    catch (Exception $e)
    {
        $this->lasterror=$e->getMessage();
        return new STREAMResponse(false, $this->lasterror,null);

    } 
    
}

//	Access the status of a specified order.
public function TrackOrder($sOrderRef)
{

    if (!$this->isInitialised) return new STREAMResponse(false, "ERR - STREAM API connection not initialised / authenticated",null);
    try
    {
    
   	    $header = new SOAPHeader($this->namespace, 'AuthenticationToken', $this->AuthenticationToken);      
 	
    
	$body=array( 
    "TrackOrder" => array( 
        "sOrderRef"        => $sOrderRef
	));
    $result=$this->client->__soapCall("TrackOrder",$body,NULL, $header);
    

    $JobStatus=$result->TrackOrderResult;
    
   
    if ($JobStatus->requestSuccessful)
    {
    return new STREAMResponse(true, "OK",$JobStatus->m_jobsStatus->SOAPjobStatus);   
    }
    else
    {
     return new STREAMResponse(false, "ERR " . $JobStatus->m_errors->description,null);         
    }   


    }
    catch (Exception $e)
    {
        $this->lasterror=$e->getMessage();
        return new STREAMResponse(false, $this->lasterror,null);

    } 
    
}


//	Access status of a number of orders, based on date range.
//	Use the class's convertDateToDateTime to convert dd/mm/yyyy dates to the required format.
public function TrackOrders($dtTrackFrom, $dtTrackUntil, $bThisUserOnly=false)
{

    if (!$this->isInitialised) return new STREAMResponse(false, "ERR - STREAM API connection not initialised / authenticated",null);
    if ($dtTrackFrom=='') return new STREAMResponse(false, "ERR - Please specify start date",null);
    if ($dtTrackUntil=='') return new STREAMResponse(false, "ERR - Please specify end date",null);    
    
    //  Convert dates to the XML format...
    
    $dtTrackFrom=$this->convertDateToDateTime($dtTrackFrom);
    $dtTrackUntil=$this->convertDateToDateTime($dtTrackUntil);    
    
    
    try
    {

    
   	    $header = new SOAPHeader($this->namespace, 'AuthenticationToken', $this->AuthenticationToken);      
 	
    
	$body=array( 
    "TrackOrders" => array( 
        "dtTrackFrom"        => $dtTrackFrom,
        "dtTrackUntil"      => $dtTrackUntil,
        "bThisUserOnly"     => $bThisUserOnly
	));
    
    $result=$this->client->__soapCall("TrackOrders",$body,NULL, $header);
    

    $JobStatus=$result->TrackOrdersResult;
    
  
   
    if ($JobStatus->requestSuccessful)
    {
    return new STREAMResponse(true, "OK",$JobStatus->m_jobsStatus->SOAPjobStatus);   
    }
    else
    {
     return new STREAMResponse(false, "ERR " . $JobStatus->m_errors->description,null);         
    }       
    
    }
    catch (Exception $e)
    {
        $this->lasterror=$e->getMessage();
        return new STREAMResponse(false, $this->lasterror,null);

    } 
    
}


/*=============================================================================================

RETRIEVAL METHODS
The following methods access the Retrieve functionality of the STREAM API

==============================================================================================*/

public function RetrieveTranslatedDocument($iTranslationID)
{

    if (!$this->isInitialised) return new STREAMResponse(false, "ERR - STREAM API connection not initialised / authenticated",null);
    try
    {

   	    $header = new SOAPHeader($this->namespace, 'AuthenticationToken', $this->AuthenticationToken);      
 	
    
	    $body=array( 
        "RetrieveTranslatedDocument" => array( 
            "idTranslation"        => $iTranslationID
	    ));
        $result=$this->client->__soapCall("RetrieveTranslatedDocument",$body,NULL, $header);
        $document=base64_decode($result);
    
   
        return new STREAMResponse(true, "OK",$document);   
    
    
    
    

    }
    catch (Exception $e)
    {
        $this->lasterror=$e->getMessage();
        return new STREAMResponse(false, $this->lasterror,null);

    } 
    
}



/*=============================================================================================

SUPPORT METHODS
The following methods are utility methods for accessing the STREAM API

==============================================================================================*/
public function parseType($tmp)
{
    if ($tmp==DRAFT) return "Draft";
    if ($tmp==PREMIUM) return "Premium";    
    if ($tmp==DRAFT_EXPRESS) return "Draft Express";        
    if ($tmp==PREMIUM_EXPRESS) return "Premium Express";        
    
}
    
//	Display a DateTimeStamp as a dd/mm/yyyy date
public function displayDate($tmpdate)
{

    $date = new DateTime($tmpdate);
    return $date->format("d/m/Y H:i:s");

}


//	Convert dd/mm/yyyy to DateTime value for use by API
public function convertDateToDateTime($tmpdate)
{
    $date = new DateTime($tmpdate);
    return $date->format(CONST_API_DATETIMESTAMP);
}



}   //  End of Class Definition


//	Definition of STREAMResponse class that is used
//	for returning data from API
class STREAMResponse
{

    var $success;
    var $statusmessage;
    var $returndata;
    
    function __construct($success, $statusmessage,$returndata)
    {
        $this->success=$success;
        $this->statusmessage=$statusmessage;
        $this->returndata=$returndata;
    
    }
    

}



?>